-- -----------------------------------------------------------------------------
-- OpenSi : Outils libres de gestion d'entreprise                             --
-- Copyright (C) 2003 Speedinfo.fr S.A.R.L.                                   --
-- Contact: contact@opensi.org                                                --
--                                                                            --
-- This program is free software; you can redistribute it and/or              --
-- modify it under the terms of the GNU General Public License                --
-- as published by the Free Software Foundation; either version 2             --
-- of the License, or (at your option) any later version.                     --
--                                                                            --
-- This program is distributed in the hope that it will be useful,            --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of             --
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               --
-- GNU General Public License for more details.                               --
--                                                                            --
-- You should have received a copy of the GNU General Public License          --
-- along with this program; if not, write to the Free Software                --
-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. --
-- -----------------------------------------------------------------------------

-- SCHEMA BASE DE DONNES OPENSI << GENERAL >>

GRANT ALL PRIVILEGES on opensi.* to 'opensi'@'localhost' identified by 'your_opensi_DbPassword';

create database opensi;

use opensi;

create table DOSSIER (
  Dossier_Id       varchar(8) not null,         -- Identifiant dossier
  Raison_Sociale   varchar(50) default '',      -- Nom de l'entreprise
  Enseigne         varchar(50) default '',      -- Enseigne
  Adresse          varchar(150) default '',     -- Adresse de la socit
  Comp_Adresse     varchar(50) default '',      -- Complment d'adresse
  Code_Postal      varchar(10) default '',      -- Code postal
  Ville            varchar(50) default '',      -- Ville
  Monnaie_Tenue    varchar(10) default '',      -- Monnaie de tenue des comptes
  Num_SIRET        varchar(14) default '',      -- Numro de SIRET
  Code_NAF         varchar(10) default '',      -- Code NAF/APE
  Typologie        varchar(2) default 'AA',     -- Typologie de l'entreprise (AN=Activit de ngoce, PS=Production de service, AA=Autre activit)
  Type_Societe     varchar(11) default 'SARL',  -- Type de socit (SARL, SA, EURL...)
  Expert           varchar(40) default '',      -- Expert comptable charg du dossier
  Date_Creation    bigint unsigned default 0,   -- Date de cration de la socit
  Duree_Societe    tinyint unsigned default 0,  -- Dure de la socit en annes (de 1  99)
  Montant_Capital  decimal(14,2) default 0,     -- Montant du capital de dpart
  Nb_Parts         smallint unsigned default 0, -- Nombre de parts ou d'actions
  Email            varchar(60) default '',      -- Email de la socit
  Telephone        varchar(20) default '',      -- Numro de tlphone
  Fax              varchar(20) default '',      -- Numro de fax
  Regime_Fiscal    char(2) default 'IR',        -- Rgime fiscal (IR=Impt sur le revenu, IS=Impt sur les socits)
  Regime_Groupe    char(1) default 'n',         -- Rgime de groupe (y=oui/n=non)
  Centre_Impot     varchar(60) default '',      -- Centre des impts dont dpend la socit
  Tresorerie       varchar(60) default '',      -- Trsorerie dont dpend la socit
  Centre_Gestion   varchar(60) default '',      -- Centre de gestion agr
	Site_Web         varchar(60) default '',      -- Site web de la socit
	Num_TVA_Intra    char(13) default '',         -- Numro de TVA intracommunautaire
	Ville_RCS        varchar(50) default '',      -- Ville RCS (immatriculation)
  Code_Plan        int unsigned default 1,      -- Code du plan comptable
  primary key(Dossier_Id)
);


create table EXERCICE (
  Dossier_Id       varchar(8) not null,         -- Identifiant dossier
  Num_Exercice     tinyint unsigned not null,   -- Numro de l'exercice
  Debut_Exercice   bigint unsigned,             -- Date de dbut d'exercice
  Fin_Exercice     bigint unsigned,             -- Date de fin d'exercice
  Duree_Exercice   tinyint unsigned,            -- Dure de l'exercice
  Nom_Base         varchar(16),                 -- Nom de la base (prefixe=CPTA_+Num_Exercice+_+ Dossier_Id)
  Bloque           tinyint unsigned default 0,  -- L'exercice est-il bloqu ? (clotur)
	Verrouille       tinyint unsigned default 0,  -- L'exercice est-il verrouill ? (en attente de retour transfert)
  primary key(Dossier_Id, Num_Exercice)
);


create table UTILISATEUR (
  Login            varchar(15) not null,    		-- Identifiant utilisateur
  Password         varchar(55) not null,    		-- Mot de passe
	Civilite         tinyint unsigned default 0,  -- Civilit de l'utilisateur (M=1,Mme=2,Mlle=3)
  Nom              varchar(30) default '',  		-- Nom de l'utilisateur
  Prenom           varchar(30) default '',  		-- Prnom de l'utilisateur
  Administrateur   tinyint unsigned default 0,
  Fonction         varchar(30) default '',  		-- Fonction de l'utilisateur
  primary key(Login)
);

-- Droits des utilisateurs sur les dossiers
create table USER_SOCIETE (
  Login            varchar(15) not null,   -- Identifiant utilisateur
  Dossier_Id       varchar(8) not null,    -- Numro de dossier gr par l'utilisateur
  Manager          tinyint unsigned not null default 0,
  Comptabilite     tinyint unsigned not null default 1,
  Commerciale      tinyint unsigned not null default 1,
  primary key(Login, Dossier_Id)
);

-- Droits des utilisateurs sur les journaux d'un dossier
create table USER_DOSSIER_JOURNAL (
	Login            varchar(15) not null,   -- Identifiant utilisateur
  Dossier_Id       varchar(8) not null,    -- Numro de dossier gr par l'utilisateur
	Code_Journal     char(3) not null,       -- Code journal gr par l'utilisateur
  primary key(Login, Dossier_Id, Code_Journal)
);


create table LISTE_TRESORERIE (
  Nom_Tresorerie   varchar(60) not null,
  primary key(Nom_Tresorerie)
);

create table LISTE_C_IMPOT (
  Nom_Centre       varchar(60) not null,
  primary key(Nom_Centre)
);


-- Liste des exports
create table EXPORT (
	Export_Id 			int unsigned not null,
	Nom_Export      varchar(20),
	primary key(Export_Id)
);

-- Liste des formats d'export
create table FORMAT_EXPORT (
	Code_Export     varchar(15) not null,
	Export_Id       int unsigned,
	Nom_Format      varchar(30),
	primary key(Code_Export)
);


-- Liste des imports
create table IMPORT (
	Import_Id       int unsigned not null,
	Nom_Import      varchar(20),
	primary key(Import_Id)
);

-- Liste des formats d'import
create table FORMAT_IMPORT (
	Code_Import     varchar(15) not null,
	Import_Id       int unsigned,
	Nom_Format      varchar(50),
	primary key(Code_Import)
);


create table CIVILITE (
	Civ_Id       tinyint unsigned not null, -- Identifiant de la civilit
	Civ_Courte   varchar(4),                -- Civilit abrge
	Civ_Longue   varchar(12),               -- Civilit entire
	primary key(Civ_Id)
);


-- Liste des taux de TVA
create table TAUX_TVA (
	Code_TVA        int unsigned not null auto_increment,  -- Code de TVA
	Taux_TVA        decimal(4,2) default 0,                -- Taux de TVA
	Taux_NPR        decimal(4,2) default 0,                -- Taux de TVA NPR
	primary key(Code_TVA)
);


create table DOSSIER_TAUX_TVA (
  Code_TVA         int unsigned not null,                 -- Code de TVA
  Dossier_Id       varchar(8) not null,                   -- Numro de dossier associ aux compte de TVA
  Compte_TVA_Achats varchar(8) default '',                -- numro du compte associ  la TVA
  Compte_TVA_Ventes varchar(8) default '',                -- numro du compte associ  la TVA
  primary key(Code_TVA, Dossier_Id)
);


-- Dfini l'ordre d'affichage des journaux par type
create table ORDRE_JOURNAUX (
	Type_Journal     char(2) not null,		-- Type de journal
	Ordre_Affichage  tinyint unsigned,		-- Numero d'ordre d'affichage
	primary key(Type_Journal)
);


-- Paramtrages du dossier
create table PARAM_DOSSIER (
  Dossier_Id                  varchar(8) not null,            -- Identifiant dossier
	Mode_Tarif                  char(1) default 'G',            -- Mode de tarification (G=Grille,Q=Quantit)
	Date_Gen                    bigint unsigned default 0,      -- Dernire date de facturation globale
	Date_Factu                  bigint unsigned default 0,      -- Date limite de facturation
	Liste_Fact                  text default '',                -- Liste des ids des dernires factures automatiques
	Com_Fact                    tinytext default '',            -- Commentaires imprimables sur toutes les factures
	Com_BL                      tinytext default '',            -- Commentaires imprimables sur tous les BLs
	Imp_Nom_Devis               tinyint unsigned default 0,     -- Impression nomenclature sur devis
	Imp_Nom_OF                  tinyint unsigned default 0,     -- Impression nomenclature sur of
	Imp_Nom_Facture             tinyint unsigned default 0,     -- Impression nomenclature sur facture
	Imp_Nom_Bon                 tinyint unsigned default 0,     -- Impression nomenclature sur bl
	Imp_Nom_Fiche               tinyint unsigned default 0,     -- Impression nomenclature sur fiche
	Imp_Nom_BP                  tinyint unsigned default 0,     -- Impression nomenclature sur BP
	Imp_Nom_BCF                 tinyint unsigned default 0,     -- Impression nomenclature sur BC fournisseur
	Imp_Desc1_Devis             tinyint unsigned default 0,     -- Impression description 1 sur devis
	Imp_Desc1_OF                tinyint unsigned default 0,     -- Impression description 1 sur of
	Imp_Desc1_Facture           tinyint unsigned default 0,     -- Impression description 1 sur facture
	Imp_Desc1_Bon               tinyint unsigned default 0,     -- Impression description 1 sur bl
	Imp_Desc1_Fiche             tinyint unsigned default 0,     -- Impression description 1 sur fiche
	Imp_Desc1_BP                tinyint unsigned default 0,     -- Impression description 1 sur BP
	Imp_Desc1_BCF               tinyint unsigned default 0,     -- Impression description 1 sur BC fournisseur
	Imp_Desc2_Devis             tinyint unsigned default 0,     -- Impression description 2 sur devis
	Imp_Desc2_OF                tinyint unsigned default 0,     -- Impression description 2 sur of
	Imp_Desc2_Facture           tinyint unsigned default 0,     -- Impression description 2 sur facture
	Imp_Desc2_Bon               tinyint unsigned default 0,     -- Impression description 2 sur bl
	Imp_Desc2_Fiche             tinyint unsigned default 0,     -- Impression description 2 sur fiche
	Imp_Desc2_BP                tinyint unsigned default 0,     -- Impression description 2 sur BP
	Imp_Desc2_BCF               tinyint unsigned default 0,     -- Impression description 2 sur BC fournisseur
	Coeff_1                     decimal(7,5),                   -- Coefficient tarif 1 par dfaut
	Coeff_2                     decimal(7,5),                   -- Coefficient tarif 2 par dfaut
	Coeff_3                     decimal(7,5),                   -- Coefficient tarif 3 par dfaut
	Coeff_4                     decimal(7,5),                   -- Coefficient tarif 4 par dfaut
	Coeff_5                     decimal(7,5),                   -- Coefficient tarif 5 par dfaut
	Logo_Adr                    tinyint unsigned default 0,     -- Le logo contient les infos de la socit (0=non,1=oui)
	Code_Journal_Achat          char(3) default 'AC',           -- Code journal d'achat par dfaut
	Code_Journal_Vente          char(3) default 'VE',           -- Code journal de vente par dfaut
	Numero_Compte_Clients       varchar(8) default '01000000',  -- Compte clients divers
	Numero_Compte_Fournisseurs  varchar(8) default '08000000',  -- Compte fournisseurs divers
	Numero_Compte_Achat         varchar(8) default '60700000',  -- Compte d'achat par dfaut
	Numero_Compte_Vente         varchar(8) default '70700000',  -- Compte de vente par dfaut
	Numero_Compte_Port_AC       varchar(8) default '62410000',  -- Compte frais de port  l'achat
	Numero_Compte_Port_VE       varchar(8) default '70850000',  -- Compte frais de port  la vente
	Numero_Compte_Escompte_AC   varchar(8) default '76500000',  -- Compte d'escompte  l'achat
	Numero_Compte_Escompte_VE   varchar(8) default '66500000',  -- Compte d'escompte  la vente
	Numero_Compte_Regul_AC      varchar(8) default '75800000',  -- Compte de rgularisation des paiements  l'achat
	Numero_Compte_Regul_VE      varchar(8) default '65800000',  -- Compte de rgularisation des paiements  la vente
	Numero_Compte_Subventions   varchar(8) default '74000000',  -- Compte de subventions
	Transfert_Reglements        tinyint unsigned default 1,     -- Transfert des rglements en compta (0=non,1=oui)   
	Modele_Etiquette            varchar(10) default 'STD01',    -- Modle d'tiquette par dfaut
	Lien_Fichier                varchar(100) default 'file://', -- debut du lien des fichiers
	Lien_Distant                varchar(100) default 'file://', -- debut du lien de l'acces distant au fichier
	Dossier_Fichier             varchar(100) default '',        -- dossier ou sont les fichiers
	Vente_TTC                   tinyint unsigned default 0,     -- facturation par dfaut en ht(0) ou ttc(1)
	Type_Calcul_Stock           tinyint unsigned default 0,     -- 0 = calcul standard, 1 = calcul avec rservation
	BL_Chiffre                  tinyint unsigned default 0,     -- 0 = BL non chiffr par dfaut, 1 = BL chiffr par dfaut
  Duree_Reservation           int unsigned default 0,         -- nombre de jours de rservation des produits 0 : pas de rservation
	primary key(Dossier_Id)
);


create table PLAN_COMPTABLE (
  Code_Plan         int unsigned not null auto_increment, -- Code du plan comptable
  Libelle           varchar(254) default '',              -- Libell du plan comptable
  primary key(Code_plan)
);


create table CLASSE_PLAN_COMPTABLE (
  Code_Plan         int unsigned not null,     -- Code du plan comptable
  Numero_Classe     int unsigned not null,     -- numero de la classe
  Libelle_Classe    varchar(254) default '',   -- Libell de la classe
  Niveau            tinyint unsigned not null, -- niveau de la classe
  Code              int unsigned not null,     -- code utilis pour afficher l arbre
  primary key(Code_plan, Numero_classe)
);


create table TITRE_CLASSE_PLAN_COMPTABLE (
  Code_Plan         int unsigned not null,  -- Code du plan comptable
  Numero_Titre      int unsigned not null,  -- numero de la classe
  Libelle_Titre     varchar(254) default '',-- Libell de la classe
  primary key(Code_plan, Numero_Titre)
);


-- liste des communes de france avec leur code postal
create table COMMUNES (
	CP          char(5),      -- code postal
	Ville       varchar(45),  -- nom de la ville en majuscule
	Ville_Min   varchar(45),  -- nom de la ville en minuscule
	Ville_Rech  char(43)      -- nom de la ville sans L' LES LA LE SAINT
);


\. InitGeneral.sql
\. PlanComptableGeneral.sql
\. Communes.sql

